import java.util.Scanner;
import java.util.InputMismatchException;
import java.io.ObjectOutputStream;
import java.io.FileOutputStream;
import java.io.ObjectInputStream;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * Writes and reads an array of 'credits' to and from
 * binary ObjectOutputStream and ObjectInputStream files.
 *
 * @author Carl B. Struck
 * @version  Copyright 2019 (c) SCCC West
 */
public class ArrayIO
{
    private static Scanner reader = new Scanner(System.in);

    /**
     * Writes an int[] array of 'credits' to a binary ObjectOutputStream file.
     *
     * @throws IOException for any file operation failure related to the 'credits.data' file
     * @throws InputMismatchException if user enters non-integer input for 'credits'
     * @throws Exception when any unexpected exception occurs
     */
    public static void output()
    {
        try
        {
            ObjectOutputStream output = new ObjectOutputStream( new FileOutputStream("credits.data") );

            int[] credits = new int[5];

            for (int index = 0; index < credits.length; index++)
            {
                System.out.print("Enter number of credits for Student No. " + (index + 1) + " ==> ");
                credits[index] = reader.nextInt();
            }

            output.writeObject(credits);
            output.close();
        }

        catch (IOException ex)
        {
            System.out.println(ex);
        }

        catch (InputMismatchException ex)
        {
            System.out.println("Non-numeric or non-integer input");
        }

        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }

    /**
     * Reads an int[] array 'credits' from a binary ObjectInputStream file and
     * writes the values of the elements of the array to the terminal window.
     *
     * @throws IOException for any file operation related to the 'credits.data' file
     * @throws Exception when any unexpected exception occurs
     */
    public static void input()
    {
        try
        {
            ObjectInputStream input = new ObjectInputStream( new FileInputStream("credits.data") );

            int[] credits = ( int[] ) input.readObject();

            for (int index = 0; index < credits.length; index++)
            {
                System.out.println("Credits for Student No. " + (index + 1) + ": " + credits[index] );
            }

            input.close();
        }

        catch (IOException ex)
        {
            System.out.println("File operation error");
        }

        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }
}
