package fileiostream;

import java.util.Scanner;
import java.util.InputMismatchException;
import java.io.FileOutputStream;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * Writes and reads student 'credits' data to and from binary FileOutputStream
 * and FileInputStream files.
 *
 * @author Carl B. Struck
 * @version Copyright 2013 (c) SCCC West
 */
public class FileIOStream
{
    private static final Scanner READER = new Scanner(System.in);

    /**
     * Driver method for FileOutputStream and FileInputStream demo.
     *
     * @param args the String[] array command line parameter
     */
    public static void main(String[] args)
    {
        try
        {
            output();
            input();
        } 
        
        catch (IOException ex)
        {
            System.out.println("File operation error");
        } 
        
        catch (InputMismatchException ex)
        {
            System.out.println("Non-numeric or non-integer input");
        } 
        
        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }

    /**
     * Writes output student 'credits' data to a binary FileOutputStream file.
     *
     * @throws IOException for any file operation failure related to the 'temp.data' file
     * @throws InputMismatchException if user enters non-integer input for 'credits'
     */
    public static void output() throws IOException
    {
        FileOutputStream output = new FileOutputStream("App_Data/temp.data");

        System.out.print("Enter number of credits==> ");
        int credits = READER.nextInt();

        while (credits != -1)
        {
            output.write(credits);

            System.out.print("Enter number of credits==> ");
            credits = READER.nextInt();
        }

        output.close();
    }

    /**
     * Reads input student 'credits' data from a binary FileInputStream file and
     * write them to the terminal window.
     *
     * @throws IOException for any file operation related to the 'temp.dat' file
     */
    public static void input() throws IOException
    {
        FileInputStream input = new FileInputStream("App_Data/temp.data");

        int credits;

        while ((credits = input.read()) != -1)
        {
            System.out.println(credits);
        }

        input.close();
    }
}

