package objectiostream;

import java.util.Scanner;
import java.util.InputMismatchException;
import java.io.ObjectOutputStream;
import java.io.FileOutputStream;
import java.io.ObjectInputStream;
import java.io.FileInputStream;
import java.io.IOException;

/**
 * Writes and reads a SuffolkResident student object to and from binary
 * ObjectOutputStream and ObjectInputStream files.
 *
 * @author Carl B. Struck
 * @version  Copyright 2013 (c) SCCC West
 */
public class ObjectIOStream
{
    private static final Scanner READER = new Scanner(System.in);

    /**
     * Driver method for ObjectOutputStream and ObjectInputStream demo.
     *
     * @param args the String[] array command line parameter
     */
    public static void main(String[] args)
    {
        try
        {
            output();
            input();
        }
        
        catch (IOException ex)
        {
            System.out.println("File operation error");
        }

        catch (InputMismatchException ex)
        {
            System.out.println("Non-numeric or non-integer input");
        }

        catch(ClassNotFoundException ex)
        {
            System.out.println("Cannot find class SuffolkResident");
        }

        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }
    
    /**
     * Writes an output SuffolkResident object with student name, grade
     * and credits data to a binary ObjectOutputStream file.
     *
     * @throws IOException for any file operation failure related to the 'temp.dat' file
     * @throws InputMismatchException if user enters non-integer input for 'credits'
     */
    public static void output() throws IOException
    {
        ObjectOutputStream output = new ObjectOutputStream(
            new FileOutputStream("temp.data") );

        SuffolkResident student = new SuffolkResident();

        System.out.print("Enter student first name==> ");
        student.setFirstName( READER.next() );

        System.out.print("Enter student last name==> ");
        student.setLastName( READER.next() );

        System.out.print("Enter student grade==> ");
        student.setGrade( READER.next() );

        System.out.print("Enter number of credits==> ");
        student.setCredits( READER.nextInt() );

        output.writeObject(student);
        output.close();
    }

    /**
     * Reads an input SuffolkResident object with student name, grade
     * and credits data from a binary ObjectInputStream file and writes
     * the object's toString() method return value to the terminal window.
     *
     * @throws IOException for any file operation related to the 'temp.dat' file
     * @throws ClassNotFoundException if the JVM cannot load the SuffolkResident class
     */
    public static void input() throws IOException, ClassNotFoundException
    {
        ObjectInputStream input = new ObjectInputStream(
            new FileInputStream("temp.data") );

        System.out.println( (SuffolkResident) input.readObject() );
            
        input.close();
    }
}
